<p align="center"><img src="docs/source/images/syssimpyplots_logo.png" alt="SysSimPyPlots" width="300"/></p>

# SysSimPyPlots

Loading, analyzing, and plotting catalogs generated from the SysSim models.

For installation instructions, tutorials, and detailed documentation, [read the documentation](https://syssimpyplots.readthedocs.io/).
